@@ -99,7 +99,6 @@ class ControlView(object):
                 bags.append(bag)
             bags.extend(ADMIN_BAGS)
 
-            filter_string = None
             search_string = None
             if req_uri.startswith('/recipes') and req_uri.count('/') == 1:
                 serialize_type, mime_type = get_serialize_type(environ)
@@ -144,10 +143,6 @@ class ControlView(object):
                         raise HTTP404('bag %s not found due to ControlView'
                                 % entity_name)
 
-            if filter_string:
-                filters, _ = parse_for_filters(filter_string)
-                for single_filter in filters:
-                    environ['tiddlyweb.filters'].insert(0, single_filter)
             if search_string:
                 search_query = environ['tiddlyweb.query'].get('q', [''])[0]
                 environ['tiddlyweb.query.original'] = search_query
